/* WLWidgetHolder */
#define WLWidgetSystemDirectory					@"/Library/Widgets"
#define WLWidgetFileExtension					@"wdgt"
#define WLWidgetBackupFileExtension				@"bak"
#define WLWidgetRevertString					@"_RevertWidgetAsItWasString_"

#define WLWidgetAccessIsPlugins               0x02
#define WLWidgetAccessIsJava                  0x04

#define WLWidgetAccessIsNetwork				  0x10
#define WLWidgetAccessIsFile                  0x20
#define WLWidgetAccessIsSystem                0x40      
#define WLWidgetAccessIsFull                  0x80


#import <Cocoa/Cocoa.h>

@interface WLWidgetHolder : NSObject
{
	NSBundle *widgetBundle;
    NSURL *widgetURL;
    NSDictionary *widgetBundleInfoDict;
    NSMutableDictionary *tempInfoDict;
	NSNumber *widgetFileSize;
	NSNumber *widgetHasATwinAndThereforIsOne;
	NSDate *widgetModificationDate;
	BOOL widgetIsWritable;
	NSArray *widgetAllowArray;
}

+ (WLWidgetHolder *) widgetHolderWithFullPath: (NSString *) fullPath;
- (WLWidgetHolder *) initWithFullPath: (NSString *) fullPath;
- (NSString *) widgetFullPath;
- (NSString *) widgetDisplayName;
- (NSString *) widgetIdentifierName;
- (NSString *) oldIdentifierName;
- (NSString *) widgetPublicIconPath;
- (NSImage *) widgetPublicIcon;
- (NSString *) widgetKindAsImagePath;
- (NSImage *) widgetIndicationFlagIcon;
- (NSNumber *) widgetFileSize;
- (NSString *) widgetFileSizeAsString;
- (NSDate *) widgetModificationDate;
- (NSString *) widgetModificationDateAsString;
- (NSString *) widgetVersionNumber;
- (NSString *) widgetCopyright;
- (NSString *) widgetMainURLAsString;
- (NSURL *) widgetMainURL;

- (void) setWidgetMainURLAsString: (NSString *) newURL;
- (void) setWidgetMainURL: (NSURL *) newURL;
- (void) setWidgetFullPath: (NSString *) newPath;
- (void) setWidgetFileSize: (NSNumber *) newSize;
- (void) setWidgetModificationDate: (NSDate *) newDate;
- (void) setWidgetIdentifierName:(NSString *)newString;

-(void)changeWidgetValuesForKeys: (NSArray *) keys;

-(BOOL) widgetIsLoaded;
-(BOOL) widgetIsWritable;

-(NSNumber *) widgetUsesMultipleInstances;
-(NSNumber *) widgetUsesJava;
-(NSNumber *) widgetUsesInternetPlugIns;
-(NSNumber *) widgetHasFileAccess;
-(NSNumber *) widgetHasNetworkAccess;
-(NSNumber *) widgetHasSystemAccess;
-(NSNumber *) widgetHasFullAccess;

-(BOOL) widgetUsesMultipleInstancesAsBool;
-(BOOL) widgetUsesJavaAsBool;
-(BOOL) widgetUsesInternetPlugInsAsBool;
-(BOOL) widgetHasFileAccessAsBool;
-(BOOL) widgetHasNetworkAccessAsBool;
-(BOOL) widgetHasSystemAccessAsBool;
-(BOOL) widgetHasFullAccessAsBool;

-(void) setWidgetUsesMultipleInstances: (NSNumber *) newNumber;
-(void) setWidgetUsesJava: (NSNumber *) newNumber;
-(void) setWidgetUsesInternetPlugIns: (NSNumber *) newNumber;
-(void) setWidgetHasFileAccess: (NSNumber *) newNumber;
-(void) setWidgetHasNetworkAccess: (NSNumber *) newNumber;
-(void) setWidgetHasSystemAccess: (NSNumber *) newNumber;
-(void) setWidgetHasFullAccess: (NSNumber *) newNumber;

-(void) setWidgetUsesMultipleInstancesAsBool: (BOOL) newVal;
-(void) setWidgetUsesJavaAsBool: (BOOL) newVal;
-(void) setWidgetUsesInternetPlugInsAsBool: (BOOL) newVal;
-(void) setWidgetHasFileAccessAsBool: (BOOL) newVal;
-(void) setWidgetHasNetworkAccessAsBool: (BOOL) newVal;
-(void) setWidgetHasSystemAccessAsBool: (BOOL) newVal;
-(void) setWidgetHasFullAccessAsBool: (BOOL) newVal;

-(unsigned int) widgetSafetyIndexAsInt;
-(NSNumber *) widgetSafetyIndex;
-(NSNumber *) widgetWidth;
-(NSNumber *) widgetHeight;

-(void) setWidgetWidth: (NSNumber *) newVal;
-(void) setWidgetHeight: (NSNumber *) newVal;

-(void) setWidgetIsTwinAsBool: (BOOL) isTwin;
-(void) setWidgetIsTwin: (NSNumber *) isTwin;
-(BOOL) widgetIsTwinAsBool;
-(NSNumber *) widgetIsTwin;

-(NSNumber *) widgetIsRemoved;			// returns the negativ value of widgetIsInstalledAndActive
-(BOOL) widgetIsInstalledAndActive;		// resides in the correct directory with the right extension
-(BOOL) widgetIsInstalled;				// resides in one of the Widget dir
-(BOOL) widgetIsActive;					// has the right extension, and somehow correct bundle
-(BOOL) widgetIsSystemWide;				// resides in the top level Library/Widget dir
-(BOOL) widgetIsUserWide;				// resides in the User level Library/Widget dir
-(BOOL) widgetIsTrashed;				// is trashed, resides in the User level .Trash dir

//-(NSNumber *) widgetSafetyIndex;
-(NSColor *)widgetTextColor;
-(NSString *) widgetFontFamilyName;

-(void) setWidgetValue: (id) newVal forKey: (NSString *) theKey;
-(id) widgetValueForKey: (NSString *) theKey;
-(NSNumber *) widgetIsEdited;
-(void) revertWidgetValues;
-(NSString *) installButtonLabel;

@end
